@@ -18,14 +18,22 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-from . import client
+from pylls import client
 
 
 class ApiParams(dict):
     """API parameters storage
 
     Convenience class for API parameters management.
-    setitem override to skip None value items.
+    The :meth:`__setitem__` method is overridden to skip None value items.
+
+    **Example:**
+
+        >>> params = ApiParams(first=1, second=2)
+        >>> params['none'] = None
+        >>> params['third'] = 3
+        >>> print(sorted(params.items()))
+        [('first', 1), ('second', 2), ('third', 3)]
     """
     def __setitem__(self, key, value):
         if value is not None:
@@ -33,7 +41,7 @@ class ApiParams(dict):
 
 
 class Ping(client.CachetAPIEndPoint):
-    """Ping endpoint: https://docs.cachethq.io/reference#ping
+    """Ping API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -42,13 +50,15 @@ class Ping(client.CachetAPIEndPoint):
     def get(self):
         """Test that the API is responding to your requests
 
-        :return: Ping response data (:class:`dict`)
+        :return: Ping response data (:class:`str`)
+
+        .. seealso:: https://docs.cachethq.io/reference#ping
         """
         return self._get('ping')['data']
 
 
 class Version(client.CachetAPIEndPoint):
-    """Version endpoint: https://docs.cachethq.io/reference#version
+    """Version API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -57,13 +67,15 @@ class Version(client.CachetAPIEndPoint):
     def get(self):
         """Get the Cachet version
 
-        :return: Cachet version data (:class:`dict`)
+        :return: Cachet version data (:class:`str`)
+
+        .. seealso:: https://docs.cachethq.io/reference#version
         """
         return self._get('version')['data']
 
 
 class Components(client.CachetAPIEndPoint):
-    """Version endpoint: https://docs.cachethq.io/reference#get-components
+    """Components API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -72,7 +84,11 @@ class Components(client.CachetAPIEndPoint):
 
     @property
     def groups(self):
-        """Component groups endpoint object (initialized on first call)"""
+        """Component groups
+
+        Special property which point to a :class:`~pylls.cachet.ComponentGroups`
+        instance for convenience. This instance is initialized on first call.
+        """
         if not self._groups:
             self._groups = ComponentGroups(self.api_client)
         return self._groups
@@ -85,7 +101,9 @@ class Components(client.CachetAPIEndPoint):
 
         Additional named arguments may be passed and are directly transmitted
         to API. It is useful to use the API search features.
-        See https://docs.cachethq.io/docs/advanced-api-usage
+
+        .. seealso:: https://docs.cachethq.io/reference#get-components
+        .. seealso:: https://docs.cachethq.io/docs/advanced-api-usage
         """
         path = 'components'
         if component_id is not None:
@@ -98,13 +116,15 @@ class Components(client.CachetAPIEndPoint):
 
         :param str name: Name of the component
         :param int status: Status of the component; 1-4
-                           https://docs.cachethq.io/docs/component-statuses
         :param str description: Description of the component (optional)
         :param str link: A hyperlink to the component (optional)
         :param int order: Order of the component (optional)
         :param int group_id: The group ID of the component (optional)
         :param bool enabled: Whether the component is enabled (optional)
         :return: Created component data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#components
+        .. seealso:: https://docs.cachethq.io/docs/component-statuses
         """
         data = ApiParams()
         data['name'] = name
@@ -122,14 +142,16 @@ class Components(client.CachetAPIEndPoint):
 
         :param int component_id: Component ID
         :param str name: Name of the component (optional)
-        :param int status: Status of the component; 1-4 (optional)
-                           https://docs.cachethq.io/docs/component-statuses
+        :param int status: Status of the component; 1-4
         :param str description: Description of the component (optional)
         :param str link: A hyperlink to the component (optional)
         :param int order: Order of the component (optional)
         :param int group_id: The group ID of the component (optional)
         :param bool enabled: Whether the component is enabled (optional)
         :return: Updated component data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#components
+        .. seealso:: https://docs.cachethq.io/docs/component-statuses
         """
         data = ApiParams()
         data['component'] = component_id
@@ -146,13 +168,15 @@ class Components(client.CachetAPIEndPoint):
         """Delete a component
 
         :param int component_id: Component ID
-        :return: Deleted component data (:class:`dict`)
+        :return: :obj:`None`
+
+        .. seealso:: https://docs.cachethq.io/reference#delete-a-components
         """
-        return self._delete('components/%s' % component_id)['data']
+        self._delete('components/%s' % component_id)
 
 
 class ComponentGroups(client.CachetAPIEndPoint):
-    """Version endpoint: https://docs.cachethq.io/reference#get-componentgroups
+    """Component groups API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -166,7 +190,9 @@ class ComponentGroups(client.CachetAPIEndPoint):
 
         Additional named arguments may be passed and are directly transmitted
         to API. It is useful to use the API search features.
-        See https://docs.cachethq.io/docs/advanced-api-usage
+
+        .. seealso:: https://docs.cachethq.io/reference#get-componentgroups
+        .. seealso:: https://docs.cachethq.io/docs/advanced-api-usage
         """
         path = 'components/groups'
         if group_id is not None:
@@ -178,11 +204,10 @@ class ComponentGroups(client.CachetAPIEndPoint):
 
         :param str name: Name of the component group
         :param int order: Order of the component group
-        :param int collapsed: Collapse the group?
-                                0 = No.
-                                1 = Yes.
-                                2 = If a component is not Operational.
+        :param int collapsed: Collapse the group? 0-2
         :return: Created component group data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#post-componentgroups
         """
         data = ApiParams()
         data['name'] = name
@@ -198,6 +223,8 @@ class ComponentGroups(client.CachetAPIEndPoint):
         :param int order: Order of the group
         :param int collapsed: Collapse the group?
         :return: Updated component group data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#put-component-group
         """
         data = ApiParams()
         data['group'] = group_id
@@ -210,13 +237,15 @@ class ComponentGroups(client.CachetAPIEndPoint):
         """Delete a Component Group
 
         :param int group_id: Component Group ID
-        :return: Response data (:class:`dict`)
+        :return: :obj:`None`
+
+        .. seealso:: https://docs.cachethq.io/reference#delete-a-component
         """
-        return self._delete('components/groups/%s' % group_id)['data']
+        self._delete('components/groups/%s' % group_id)
 
 
 class Incidents(client.CachetAPIEndPoint):
-    """Incidents endpoint: https://docs.cachethq.io/reference#get-incidents
+    """Incidents API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -230,7 +259,9 @@ class Incidents(client.CachetAPIEndPoint):
 
         Additional named arguments may be passed and are directly transmitted
         to API. It is useful to use the API search features.
-        See https://docs.cachethq.io/docs/advanced-api-usage
+
+        .. seealso:: https://docs.cachethq.io/reference#get-incidents
+        .. seealso:: https://docs.cachethq.io/docs/advanced-api-usage
         """
         path = 'incidents'
         if incident_id is not None:
@@ -253,6 +284,8 @@ class Incidents(client.CachetAPIEndPoint):
         :param str template: The template slug to use
         :param list tplvars: The variables to pass to the template
         :return: Created incident data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#incidents
         """
         data = ApiParams()
         data['name'] = name
@@ -284,6 +317,8 @@ class Incidents(client.CachetAPIEndPoint):
         :param str template: The template slug to use
         :param list tpl_vars: The variables to pass to the template
         :return: Created incident data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#update-an-incident
         """
         data = ApiParams()
         data['name'] = name
@@ -302,13 +337,15 @@ class Incidents(client.CachetAPIEndPoint):
         """Delete an Incident
 
         :param int incident_id: Incident ID
-        :return: Deleted incident data (:class:`dict`)
+        :return: :obj:`None`
+
+        .. seealso:: https://docs.cachethq.io/reference#delete-an-incident
         """
-        return self._delete('incidents/%s' % incident_id)['data']
+        self._delete('incidents/%s' % incident_id)
 
 
 class Metrics(client.CachetAPIEndPoint):
-    """Metrics endpoint: https://docs.cachethq.io/reference#get-metrics
+    """Metrics API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -317,7 +354,11 @@ class Metrics(client.CachetAPIEndPoint):
 
     @property
     def points(self):
-        """Metric points endpoint object (initialized on first call)"""
+        """Metric points
+
+        Special property which point to a :class:`~pylls.cachet.MetricPoints`
+        instance for convenience. This instance is initialized on first call.
+        """
         if not self._points:
             self._points = MetricPoints(self.api_client)
         return self._points
@@ -330,7 +371,9 @@ class Metrics(client.CachetAPIEndPoint):
 
         Additional named arguments may be passed and are directly transmitted
         to API. It is useful to use the API search features.
-        See https://docs.cachethq.io/docs/advanced-api-usage
+
+        .. seealso:: https://docs.cachethq.io/reference#get-metrics
+        .. seealso:: https://docs.cachethq.io/docs/advanced-api-usage
         """
         path = 'metrics'
         if metric_id is not None:
@@ -338,7 +381,7 @@ class Metrics(client.CachetAPIEndPoint):
         return self.paginate_get(path, data=kwargs)
 
     def create(self, name, suffix, description, default_value, display=None):
-        """
+        """Create a new Metric
 
         :param str name: Name of metric
         :param str suffix: Metric unit
@@ -346,6 +389,8 @@ class Metrics(client.CachetAPIEndPoint):
         :param int default_value: Default value to use when a point is added
         :param int display: Display the chart on the status page
         :return: Created metric data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#metrics
         """
         data = ApiParams()
         data['name'] = name
@@ -356,16 +401,18 @@ class Metrics(client.CachetAPIEndPoint):
         return self._post('metrics', data=data)['data']
 
     def delete(self, metric_id):
-        """
+        """Delete a Metric
 
         :param int metric_id: Metric ID
-        :return: Deleted metric data (:class:`dict`)
+        :return: :obj:`None`
+
+        .. seealso:: https://docs.cachethq.io/reference#delete-a-metric
         """
-        return self._delete('metrics/%s' % metric_id)
+        self._delete('metrics/%s' % metric_id)
 
 
 class MetricPoints(client.CachetAPIEndPoint):
-    """MetricPoints endpoint: https://docs.cachethq.io/reference#get-metric-points
+    """MetricPoints API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -376,8 +423,10 @@ class MetricPoints(client.CachetAPIEndPoint):
 
         :param int metric_id: Metric ID
         :return: Metric points data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#get-metric-points
         """
-        return self._get('metrics/%s/points' % metric_id, **kwargs)
+        return self.paginate_get('metrics/%s/points' % metric_id, **kwargs)
 
     def create(self, metric_id, value, timestamp=None):
         """Add a Metric Point to a Metric
@@ -386,24 +435,28 @@ class MetricPoints(client.CachetAPIEndPoint):
         :param int value: Value to plot on the metric graph
         :param str timestamp: Unix timestamp of the point was measured
         :return: Created metric point data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#post-metric-points
         """
         data = ApiParams()
         data['value'] = value
         data['timestamp'] = timestamp
-        return self._get('metrics/%s/points' % metric_id, data=data)
+        return self._post('metrics/%s/points' % metric_id, data=data)
 
     def delete(self, metric_id, point_id):
         """Delete a Metric Point
 
         :param metric_id: Metric ID
         :param point_id: Metric point ID
-        :return: Deleted metric point data (:class:`dict`)
+        :return: :obj:`None`
+
+        .. seealso:: https://docs.cachethq.io/reference#delete-a-metric-point
         """
-        return self._delete('metrics/%s/points/%s' % (metric_id, point_id))
+        self._delete('metrics/%s/points/%s' % (metric_id, point_id))
 
 
 class Subscribers(client.CachetAPIEndPoint):
-    """Subscribers endpoint: https://docs.cachethq.io/reference#get-subscribers
+    """Subscribers API endpoint
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
@@ -416,7 +469,9 @@ class Subscribers(client.CachetAPIEndPoint):
 
         Additional named arguments may be passed and are directly transmitted
         to API. It is useful to use the API search features.
-        See https://docs.cachethq.io/docs/advanced-api-usage
+
+        .. seealso:: https://docs.cachethq.io/reference#get-subscribers
+        .. seealso:: https://docs.cachethq.io/docs/advanced-api-usage
         """
 
         return self.paginate_get('subscribers', data=kwargs)
@@ -428,6 +483,8 @@ class Subscribers(client.CachetAPIEndPoint):
         :param bool verify: Whether to send verification email
         :param list components: Components ID list, defaults to all
         :return: Created subscriber data (:class:`dict`)
+
+        .. seealso:: https://docs.cachethq.io/reference#subscribers
         """
         data = ApiParams()
         data['email'] = email
@@ -439,16 +496,25 @@ class Subscribers(client.CachetAPIEndPoint):
         """Delete a Subscriber
 
         :param int subscriber_id: Subscriber ID
-        :return: Deleted subscriber data (:class:`dict`)
+        :return: :obj:`None`
+
+        .. seealso:: https://docs.cachethq.io/reference#delete-subscriber
         """
-        return self._delete('subscribers/%s' % subscriber_id)['data']
+        self._delete('subscribers/%s' % subscriber_id)
 
 
 class Actions(client.CachetAPIEndPoint):
-    """Actions endpoint: https://docs.cachethq.io/reference#get-actions
+    """Actions API endpoint
 
     This endpoint is not implemented in Cachet 2.3 and will be released in 2.4
+
+    .. seealso:: https://docs.cachethq.io/reference#get-actions
     """
     def __init__(self, *args, **kwargs):
         """Initialization method"""
         super(Actions, self).__init__(*args, **kwargs)
+
+
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
